@@ -137,7 +137,7 @@ module Make(Dpkg : Dpkg.DB) =
     (*** Busy *)
     let busy_count = ref 0;;
     let sleep_cursor = Gdk.Cursor.create `WATCH;;
-    let normal_cursor = Gdk.Cursor.create `X_CURSOR;;
+    let normal_cursor = Gdk.Cursor.create `LEFT_PTR;;
     let i_am_busy () =
       incr busy_count;
       Gdk.Window.set_cursor window#misc#window sleep_cursor; Gdk.X.flush ();;
@@ -1376,7 +1376,7 @@ module Make(Dpkg : Dpkg.DB) =
           | Glib.Convert.Error(e,s) ->
               error_display#show_message
               (sf "Illegal, non ISO-8859-1 characters in query. (%s)" s);
-          | Publication.No_issue -> flash "Database unavailable."
+          | Publication.No_issue -> flash "Database unavailable. Try: apt-get update"
           | x ->
               flash (sf "Exception: %S" (Printexc.to_string x))
         method launch =
@@ -1808,7 +1808,7 @@ module Make(Dpkg : Dpkg.DB) =
                 database#publish `Everyone db';
                 after db'
              with
-             | x -> debug 0 (sf "Could not load database: %s" (Printexc.to_string x))),
+             | x -> debug 0 (sf "Could not load database: %s. Try: apt-get update\n" (Printexc.to_string x))),
            "Load database...")
       with
       | Computation.Busy -> flash ("Busy...")
